/**************************************************
Do-file replicating the results of:
	
Title: Leading-effect, Risk-taking and Sabotage in Two-stage Tournaments: Evidence from a Natural Experiment
Authors: Frank Mueller-Langer and Patrick Andreoli-Versbach
Published in: Journal of Economics and Statistics (Jahrbuecher fuer Nationaloekonomie und Statistik)

Contact author: Frank Mueller-Langer
**************************************************/

	
	clear all
	set more off 
	
********************
** Set up globals **
********************           
	 
	// Save data here: 
	global folder "[...]" 

	// Set folder where output will be saved: 
	cd "[...]" 

******************************************************************************** 
*************************** Start - First Part *********************************
********************************************************************************

**********************************
***     Import and save data   ***
**********************************

// Main data
import excel "$folder\Leading effect_Data_Replication.xlsx" , clear firstrow 

save "$folder\Leading effect_Data_Replication" , replace

**********************************
***     Preliminary tests		   ***
**********************************
clear
use "$folder\Leading effect_Data_Replication" , clear

// level of the data 
isid Team_1 Team_2 saison  second_game

// Percentage of SH teams winning
sum win if  ID ==2
// Percentage of FH teams winning
sum win if  ID ==1

// Binomial probability test SH wins 
bitest win=.5 if ID==2
//T-test SH wins 
ttest win=.5 if ID==2


// Outcome
gen Outcome=1 if ( goal_1>goal_2 & ID==1) | (goal_1<goal_2 & ID==2)
replace Outcome=2 if goal_1==goal_2
replace Outcome=3 if ( goal_1<goal_2 & ID==1) | (goal_1>goal_2 & ID==2)

foreach var of varlist Outcome {
	
	replace `var'=0 if missing(`var')
	
	}
	
// Kolmogorov-Smirnov test
ksmirnov sumgoal, by(sh)
ksmirnov Outcome , by(sh)

bys sh: sum sumgoal
ttest sumgoal, by(sh)

// power of the test
sampsi .5  .522 , sd(.5) n(573) onesamp
sampsi .5  .522 , sd(.5) power(.90) onesamp

************************************
***Table 1 - Summary of the Data ***
************************************
gen time_period55_99=(saison>=1955 & saison<=1999)
gen time_period00_04=(saison>=2000 & saison<=2004)
gen time_period05_09=(saison>=2005 & saison<=2009)
gen time_period55_09=(saison>=1955 & saison<=2009)

gen comp1 = uefachampionsleague
gen comp2 = uefapokaluefaeuropaleague
gen comp3 = comp2*(1-rundederletztensechszehn) 
gen comp4 = comp2*rundederletztensechszehn 

keep comp* time*
gen ID=_n

reshape long comp , i(ID)

drop if comp==0

gen Name="Champions League Final KO Round" if _j==1
replace Name="Europa League Overall" if _j==2
replace Name="Europa League Final KO Round" if _j==3
replace Name="Europa League KO Round of last 16" if _j==4

collapse (sum) time_period55_99 time_period00_04 time_period05_09 time_period55_09   , by(Name)

gsort -time_period55_09
 
export excel "$folder/Table1_FINAL" , replace   firstrow(variables)
clear

**********************************
***Table 2 - UEFA Regulation   ***
**********************************
use "$folder\Leading effect_Data_Replication" , clear

gen Home_win=1 if ( goal_1>goal_2 & ID==1) | (goal_1<goal_2 & ID==2)
gen Home_draw=1 if goal_1==goal_2
gen Home_defeat=1 if ( goal_1<goal_2 & ID==1) | (goal_1>goal_2 & ID==2)

foreach var of varlist Home_win Home_draw Home_defeat {
	replace `var'=0 if missing(`var')
	
	}

collapse (sum) Home_win Home_draw Home_defeat (mean) fr_w=Home_win fr_d=Home_draw fr_def=Home_defeat

clear

use "$folder\Leading effect_Data_Replication" , clear

tab KORundeentschiedendurchTor 
tab KORundeentschiedendurchElf 
tab KORundeentschiedendurchAus 
tab KORundeentschiedennachVerl

clear
*************************************************************
*** Table 4: Neutrality of Two-stage Tournament Structure ***
*************************************************************
use "$folder\Leading effect_Data_Replication" , clear

xi: logit win sh , vce(cl match)
outreg2 using Table4, replace excel  symbol(***, **, *)  keep(sh) 

xi: logit win sh i.saison*sh  , vce(cl match)
outreg2 using Table4, append excel  symbol(***, **, *)  keep(sh ) addtext(Year Dummy, Yes)

xi: logit win sh CL_SH  , vce(cl match)
outreg2 using Table4, append excel  symbol(***, **, *)  keep(sh CL_SH)

xi: logit win sh R16_SH QF_SH SF_SH , vce(cl match)
outreg2 using Table4, append excel  symbol(***, **, *)  keep(sh R16_SH QF_SH SF_SH  )

xi: logit win  sh CL_SH R16_SH QF_SH SF_SH i.saison*sh, vce(cl match)
outreg2 using Table4, append excel  symbol(***, **, *) keep(sh CL_SH R16_SH QF_SH SF_SH ) addtext(Year Dummy, Yes) ///
	sortvar( sh  R16_SH QF_SH SF_SH CL_SH ) 


******************************************************************************** 
***************************  FIGURES *******************************************
********************************************************************************

*************************************************************
*** FIGURE 2: Sum of Home and Away Goals  by Game		  ***
*************************************************************
tw hist sumgoal if second_game==1, ysc(r(0 30)) ylabel(0 (10) 30) percent lc(dkorange)   disc bfcolor(none)   ||  hist sumgoal if second_game==0, gap(15) percent lp(dash)  bfcolor(none) lc(dkgreen) disc ///
 legend(label(1 " Second Game" )  label(2 "First Game")  order(2 1)) ///
xtitle("Sum of Home and Away Team Goals") xlabel(0 (1) 10) scheme(s1color)


graph export "$folder/Figure2_FINAL.wmf" , replace 



********************************************************************
*** FIGURE 1: Results in the First Game (FG) and Second Game (SG) **		
********************************************************************
use "$folder\Leading effect_Data_Replication" , clear

keep goal_1 goal_2 ID

gen win=1 if ( goal_1>goal_2 & ID==1) | (goal_1<goal_2 & ID==2)
gen draw=1 if goal_1==goal_2
gen defeat=1 if ( goal_1<goal_2 & ID==1) | (goal_1>goal_2 & ID==2)

foreach var of varlist win draw defeat {
	replace `var'=0 if missing(`var')
	
	}
	
collapse (mean) win draw defeat (sd) sd_win=win sd_draw=draw sd_defeat=defeat (count) obs=goal_1 , by(ID)	

foreach var of varlist win draw defeat { 

	gen hi_`var' = `var' + invttail(obs-1,0.025)*(sd_`var' / sqrt(obs))
	gen lo_`var' = `var' - invttail(obs-1,0.025)*(sd_`var' / sqrt(obs))
	
		}

rename win    mean_win
rename draw   mean_draw
rename defeat mean_defeat

reshape long mean_ sd_ hi_ lo_ , i(ID) string

gsort -_j ID
gen var=_n

format mean_ %8.2f

tw rbar lo_ hi_ var if ID==1, lp(dash)  barwidth(.5) fc(none)  color(dkgreen) msize(medium)    || ///
scatter  mean_ var if ID==1,  mlabel(mean_) mlabcolor(black) mlabgap(4) msymbol(S)  color(dkgreen) mlabpo(12) ysc(r(0 .7)) ylabel(0 (.1) .7, axis(1)) || ///
rbar lo_ hi_ var if ID==2,  barwidth(.5)  fc(none)  color(dkorange) msize(medium)  || ///
scatter  mean_ var if ID==2, mlabel(mean_) mlabcolor(black) mlabgap(4) msymbol(D) color(dkorange) mlabpo(12) ysc(r(0 .7)) ylabel(0 (.1) .7, axis(1)) ///
legend(label(1 "CI(95%) FG")  label(2 "Frequency of Result in FG (%)") label(3 "CI(95%) SG") label(4 "Frequency of Result in SG (%)")  order(2 1 4 3)) ///
xtitle("") ytitle("Home, Draw and Away (%)") yscale(titlegap(2)) xlabel( 1 "Home/FG" 2 "Home/SG"  3 "Draw/FG" 4 "Draw/SG" 5 "Away/FG" 6 "Away/SG") xsize(6)  ///
scheme(s1color)

graph export "$folder/Figure1_FINAL.wmf" , replace 
clear


******************************************************************************** 
*************************Start - Effort and Sabotage ***************************
********************************************************************************


************************************
***Table 3 - Effort and Sabotage ***
************************************

** The data provided by IMPIRE AG, Munich (as of Dec. 2016, deltatre AG, www.bundesliga-datenbank.de) is protected by a confidentiality agreement **
** We provide a separate spreadsheet that unambiguously identifies the 280 games used in our study to examine proactive effort and sabotage (see Tables 3, 5 and 6) **

use "[....]" , clear

//rename 
rename FoulsbegangenHeimteam foulH
rename FoulsbegangenAuswrtsteam foulA
rename GelbeKartenHeimteam yellowH
rename GelbeKartenAuswrtsteam yellowA
rename RoteKartenHeimteam redH
rename RoteKartenAuswrtsteam redA

rename TorscheHeimteamaufdasTor shotsONgoalH
rename TorscheAuswrtsteamaufdas shotsONgoalA
rename TorscheHeimteamamTorvorbe shotsOFFgoalH
rename TorscheAuswrtsteamamTorv shotsOFFgoalA
rename EckblleHeimteam cornerH
rename EckblleAuswrtsteam cornerA

rename Viertelfin QF 
rename Halbfin SF
rename Achtelfin R16

foreach var of varlist QF SF CL {

	gen SH_`var'=SH*`var'

	}
	

**************************************************************************
***  Table 3: Summary Statistics Proactive Effort and Sabotage **
**************************************************************************
tabstat shotsONgoalH shotsONgoalA shotsOFFgoalH shotsOFFgoalA cornerH cornerA ///
		foulH foulA yellowH yellowA redH redA ///
, s(mean sd min max N) columns(s)

foreach var  in shotsONgoal shotsOFFgoal corner foul yellow red  {

	ttest `var'H=`var'A

	}

************************************
***  Table 5: Proactive Effort 	 ***
************************************

local var "SH QF SF"

reg shotsONgoalH `var' , vce(cl knockoutID)
outreg2 using Table5, replace excel  symbol(***, **, *)  
reg shotsONgoalA `var'  , vce(cl knockoutID)
outreg2 using Table5, append excel  symbol(***, **, *)  
reg shotsOFFgoalH `var' , vce(cl knockoutID)
outreg2 using Table5, append excel  symbol(***, **, *)  
reg shotsOFFgoalA `var' , vce(cl knockoutID)
outreg2 using Table5, append excel  symbol(***, **, *)  
reg cornerH `var' , vce(cl knockoutID)
outreg2 using Table5, append excel  symbol(***, **, *)  
reg cornerA `var' , vce(cl knockoutID)
outreg2 using Table5, append excel  symbol(***, **, *)  


areg shotsONgoalH `var' , absorb(knockoutID) vce(cl knockoutID)
outreg2 using Table5, append excel  symbol(***, **, *)  
areg shotsONgoalA `var' , absorb(knockoutID) vce(cl knockoutID)
outreg2 using Table5, append excel  symbol(***, **, *)  
areg shotsOFFgoalH `var' , absorb(knockoutID) vce(cl knockoutID)
outreg2 using Table5, append excel  symbol(***, **, *)  
areg shotsOFFgoalA `var' , absorb(knockoutID) vce(cl knockoutID)
outreg2 using Table5, append excel  symbol(***, **, *)  
areg cornerH `var' , absorb(knockoutID) vce(cl knockoutID)
outreg2 using Table5, append excel  symbol(***, **, *)  
areg cornerA `var' , absorb(knockoutID) vce(cl knockoutID)
outreg2 using Table5, append excel  symbol(***, **, *)  


************************************
***     Table 6: Sabotage	 	 ***
************************************

local var "SH QF SF "

reg foulH `var' , vce(cl knockoutID)
outreg2 using Table6, replace excel  symbol(***, **, *)  
reg foulA `var'  , vce(cl knockoutID)
outreg2 using Table6, append excel  symbol(***, **, *)  
reg yellowH `var' , vce(cl knockoutID)
outreg2 using Table6, append excel  symbol(***, **, *)  
reg yellowA `var' , vce(cl knockoutID)
outreg2 using Table6, append excel  symbol(***, **, *)  
reg redH `var' , vce(cl knockoutID)
outreg2 using Table6, append excel  symbol(***, **, *)  
reg redA `var' , vce(cl knockoutID)
outreg2 using Table6, append excel  symbol(***, **, *)  

areg foulH `var' , absorb(knockoutID) vce(cl knockoutID)
outreg2 using Table6, append excel  symbol(***, **, *)  
areg foulA `var' , absorb(knockoutID) vce(cl knockoutID)
outreg2 using Table6, append excel  symbol(***, **, *)  
areg yellowH `var' , absorb(knockoutID) vce(cl knockoutID)
outreg2 using Table6, append excel  symbol(***, **, *)  
areg yellowA `var' , absorb(knockoutID) vce(cl knockoutID)
outreg2 using Table6, append excel  symbol(***, **, *)  
areg redH `var' , absorb(knockoutID) vce(cl knockoutID)
outreg2 using Table6, append excel  symbol(***, **, *)  
areg redA `var' , absorb(knockoutID) vce(cl knockoutID)
outreg2 using Table6, append excel  symbol(***, **, *)  




******************************************************************************** 
********************** END OF REPLICATION DO-FILE ******************************
********************************************************************************
